import { AxiosRequestConfig, InternalAxiosRequestConfig } from "axios";

export type RequestConfig = {
  baseURL: string;
  contentType?: ContentType;
  aesKey?: string;
  cryptoConfig?: Partial<CryptoConfig>;
  timeout?: number;
} & AxiosRequestConfig;

export type RequsetsServiceConfig = {
  baseURLs: { [key: string]: RequestConfig };
};

export type CryptoConfig = {
  encryptKey: string;
  /** 布尔值，表示是否对URL进行加密。默认值为false */
  encryptUrl: boolean;
  /** 布尔值，表示是否对请求参数进行加密。默认值为false */
  encryptParams: boolean;
  /** 布尔值，表示是否对response的data进行解密。 */
  decryptRes: boolean;
};

export type InternalRequestConfig = {
  encryptUrl?: boolean;
  encryptParams?: boolean;
  decryptRes?: boolean;
} & InternalAxiosRequestConfig;

export enum ContentType {
  JSON = "application/json;charset=utf-8",
  STREAM = "application/octet-stream",
  HTML = "text/html;charset=utf-8",
  PLAIN = "text/plain;charset=utf-8",
  FORM = "application/x-www-form-urlencoded;charset=utf-8",
}
